@@ -48,8 +48,8 @@ public:
     void remove(const Akonadi::Item &item) Q_DECL_OVERRIDE;
     void remove(const Akonadi::Collection &item) Q_DECL_OVERRIDE;
     void move(const Akonadi::Item::Id &itemId,
-              const Akonadi::Entity::Id &from,
-              const Akonadi::Entity::Id &to) Q_DECL_OVERRIDE;
+              const Akonadi::Collection::Id &from,
+              const Akonadi::Collection::Id &to) Q_DECL_OVERRIDE;
 
     void commit() Q_DECL_OVERRIDE;
 
