@@ -25,9 +25,8 @@
 #include "akonotesindexer.h"
 #include "calendarindexer.h"
 #include <AkonadiCore/ServerManager>
-#include <KGlobal>
-#include <KStandardDirs>
 #include <QDir>
+#include <QStandardPaths>
 #include <xapian/error.h>
 #include <xapian/database.h>
 #include <xapian/query.h>
@@ -39,7 +38,7 @@ Index::Index(QObject *parent)
 {
     m_commitTimer.setInterval(1000);
     m_commitTimer.setSingleShot(true);
-    connect(&m_commitTimer, SIGNAL(timeout()), this, SLOT(commit()));
+    connect(&m_commitTimer, &QTimer::timeout, this, &Index::commit);
 }
 
 Index::~Index()
@@ -149,7 +148,7 @@ void Index::updateFlags(const Akonadi::Item::List &items, const QSet<QByteArray>
     }
 }
 
-void Index::remove(const QSet< Akonadi::Entity::Id > &ids, const QStringList &mimeTypes)
+void Index::remove(const QSet<Akonadi::Item::Id> &ids, const QStringList &mimeTypes)
 {
     const QList<AbstractIndexer *> indexers = indexersForMimetypes(mimeTypes);
     Q_FOREACH (const Akonadi::Item::Id &id, ids) {
@@ -317,7 +316,7 @@ void Index::commit()
     }
 }
 
-void Index::findIndexedInDatabase(QSet<Akonadi::Entity::Id> &indexed, Akonadi::Entity::Id collectionId, const QString &dbPath)
+void Index::findIndexedInDatabase(QSet<Akonadi::Item::Id> &indexed, Akonadi::Collection::Id collectionId, const QString &dbPath)
 {
     Xapian::Database db;
     try {
@@ -338,7 +337,7 @@ void Index::findIndexedInDatabase(QSet<Akonadi::Entity::Id> &indexed, Akonadi::E
     }
 }
 
-void Index::findIndexed(QSet<Akonadi::Entity::Id> &indexed, Akonadi::Entity::Id collectionId)
+void Index::findIndexed(QSet<Akonadi::Item::Id> &indexed, Akonadi::Collection::Id collectionId)
 {
     findIndexedInDatabase(indexed, collectionId, emailIndexingPath());
     findIndexedInDatabase(indexed, collectionId, contactIndexingPath());
@@ -377,13 +376,30 @@ QString Index::dbPath(const QString &dbName) const
     if (!m_overridePrefixPath.isEmpty()) {
         return QString::fromLatin1("%1/%2/").arg(m_overridePrefixPath, dbName);
     }
-    QString basePath = QStringLiteral("baloo");
+
+    // First look into the old location from Baloo times in ~/.local/share/baloo,
+    // because we don't migrate the database files automatically.
+    QString basePath;
     if (Akonadi::ServerManager::hasInstanceIdentifier()) {
-        basePath = QString::fromLatin1("baloo/instances/%1").arg(Akonadi::ServerManager::instanceIdentifier());
+        basePath = QStringLiteral("baloo/instances/%1").arg(Akonadi::ServerManager::instanceIdentifier());
+    } else {
+        basePath = QStringLiteral("baloo");
     }
-    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QString::fromLatin1("/%1/%2/").arg(basePath, dbName);
-    QDir().mkpath(path);
-    return path;
+    QString dbPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/%1/%2/").arg(basePath, dbName);
+    if (QDir(dbPath).exists()) {
+        return dbPath;
+    }
+
+    // If the database does not exist in old Baloo folders, than use the new
+    // location in Akonadi's datadir in ~/.local/share/akonadi/search_db.
+    if (Akonadi::ServerManager::hasInstanceIdentifier()) {
+        basePath = QStringLiteral("akonadi/instance/%1/search_db").arg(Akonadi::ServerManager::instanceIdentifier());
+    } else {
+        basePath = QStringLiteral("akonadi/search_db");
+    }
+    dbPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/%1/%2/").arg(basePath, dbName);
+    QDir().mkpath(dbPath);
+    return dbPath;
 }
 
 QString Index::emailIndexingPath() const
