@@ -39,7 +39,7 @@ using namespace Akonadi::Search;
 
 const int defaultLimit = 100000;
 
-class Akonadi::Search::Query::Private
+class Q_DECL_HIDDEN Akonadi::Search::Query::Private
 {
 public:
     Private()
@@ -334,12 +334,12 @@ Query Query::fromJSON(const QByteArray &arr)
     }
 
     if (map.contains(QStringLiteral("sortingOption"))) {
-        int option = map.value("sortingOption").toInt();
+        int option = map.value(QStringLiteral("sortingOption")).toInt();
         query.d->m_sortingOption = static_cast<SortingOption>(option);
     }
 
     if (map.contains(QStringLiteral("sortingProperty"))) {
-        query.d->m_sortingProperty = map.value("sortingProperty").toString();
+        query.d->m_sortingProperty = map.value(QStringLiteral("sortingProperty")).toString();
     }
 
     if (map.contains(QStringLiteral("customOptions"))) {
